# Contributing

Follow these guidelines if you'd like to contribute to the project!

---

### Table of Contents

Read through these guidelines before you get started:

1. [Questions & Concerns](#questions--concerns)
2. [Issues & Bugs](#issues--bugs)
3. [Feature Requests](#feature-requests)
4. [Submitting Pull Requests](#submitting-pull-requests)
5. [Code Style](#code-style)

### Questions & Concerns

If you have any questions about using or developing for this project, shoot me
an [email][1]!

### Issues & Bugs

Submit an [issue][2] or [pull request][3] with a fix if you find any bugs in
the project. See [below](#submitting-pull-requests) for instructions on sending
in pull requests, and be sure to reference the [code style guide](#code-style)
first!

When submitting an issue or pull request, make sure you're as detailed as possible
and fill in all answers to questions asked in the templates. For example, an issue
that simply states "X/Y/Z isn't working!" will be ignored.

### Feature Requests

Submit an [issue][2] to request a new feature. Features fall into one of two
categories:

1. **Major**: Major changes should be discussed with me via [email][1]. I'm
always open to suggestions and will get back to you as soon as I can!
2. **Minor**: A minor feature can simply be added via a [pull request][3].

### Submitting Pull Requests

Before you do anything, make sure you check the current list of [pull requests][4]
to ensure you aren't duplicating anyone's work. Then, do the following:

1. Fork the repository and make your changes in a git branch: `git checkout -b my-branch master`
2. Read and follow the [code style guidelines][#code-style].
3. Make sure your feature or fix doesn't break the project! Test thoroughly.
4. Commit your changes, and be sure to leave a detailed commit message.
5. Push your branch to your forked repo on GitHub: `git push origin my-branch`
6. [Submit a pull request][3] and hold tight!
7. If any changes are requested by the project maintainers, make them and follow
this process again until the changes are merged.

### Code Style

Please follow the coding style conventions detailed below:

Your code should meet all [pep8](http://pep8.readthedocs.io/en/latest/) guidelines;
the only exception is that the max line length accepted is 120.

[1]: mailto:tylucaskelley@gmail.com
[2]: https://github.com/tylucaskelley/licenser/issues/new
[3]: https://github.com/tylucaskelley/licenser/compare
[4]: https://github.com/tylucaskelley/licenser/pulls
